@@ -53,27 +53,30 @@ class EAT():
         self.ranges = None        
 
 
-    def forecast(self, df):            
+    def forecast(self, df, freq=None):            
         
         # obtain dates 'forecast' -----
 
         # to be put in utils/ as a function (DRY)
         
-        input_dates = df['date'].values 
-        n_input_dates = len(input_dates)        
-        input_dates_ms = [datetime.strptime(str(input_dates[i]), "%Y-%m-%d").timestamp()*1000 for i in range(n_input_dates)]    
+        input_dates = df.index.values 
+        n_input_dates = len(input_dates)                
 
         frequency = pd.infer_freq(pd.DatetimeIndex(input_dates))
         output_dates = np.delete(pd.date_range(start=input_dates[-1], 
             periods=self.h+1, freq=frequency).values, 0).tolist()  
         
-        df_dates = pd.DataFrame({'date': output_dates})
-        output_dates = pd.to_datetime(df_dates['date']).dt.date                                
+        df_output_dates = pd.DataFrame({'date': output_dates})
+        output_dates = pd.to_datetime(df_output_dates['date']).dt.date                                
 
         # obtain time series forecast -----
 
-        input_series = df.drop(columns=['date']).values
-        y = stats.ts(FloatVector([item for sublist in input_series.tolist() for item in sublist]))
+        input_series = df.values
+        if freq is None: 
+            y = stats.ts(FloatVector([item for sublist in input_series.tolist() for item in sublist]))
+        else:     
+            y = stats.ts(FloatVector([item for sublist in input_series.tolist() for item in sublist]), 
+            frequency=freq)
         self.fcast = ahead.eatf(y=y, h=self.h, level=self.level, type_pi=self.type_pi,
                                 weights=FloatVector(self.weights))        
 
