@@ -59,9 +59,7 @@ class Ridge2Regressor():
 
     def forecast(self, df): 
 
-        assert (len(df.columns) >= 3), "Must have number of columns >= 3" 
-
-        n_series = len(df.columns) - 1
+        n_series = len(df.columns)
         averages = []
         ranges = []
 
@@ -69,24 +67,23 @@ class Ridge2Regressor():
 
         # to be put in utils/ as a function (DRY)
 
-        input_dates = df['date'].values 
+        input_dates = df.index.values 
         n_input_dates = len(input_dates)        
-        input_dates_ms = [datetime.strptime(str(input_dates[i]), "%Y-%m-%d").timestamp()*1000 for i in range(n_input_dates)]    
-
+       
         frequency = pd.infer_freq(pd.DatetimeIndex(input_dates))
         output_dates = np.delete(pd.date_range(start=input_dates[-1], 
             periods=self.h+1, freq=frequency).values, 0).tolist()  
         
-        df_dates = pd.DataFrame({'date': output_dates})
-        output_dates = pd.to_datetime(df_dates['date']).dt.date 
+        df_output_dates = pd.DataFrame({'date': output_dates})
+        output_dates = pd.to_datetime(df_output_dates['date']).dt.date                                
 
 
         # obtain time series forecast -----
 
         # to be put in utils/ as a function (DRY)
 
-        input_series = df.drop(columns=['date'])        
-        input_series_tolist = input_series.values.tolist()
+        input_series = df.values        
+        input_series_tolist = input_series.tolist()
         xx = [item for sublist in input_series_tolist for item in sublist]  
         m = stats.ts(base.matrix(FloatVector(xx), byrow=True, 
                                  nrow=len(input_series_tolist)))      
